@@ -40,7 +40,7 @@ class BaseCloudsplainingIAMCheck(BaseResourceCheck):
                             policy_statement = PolicyDocument(converted_policy_doc)
                             violations = self.cloudsplaining_analysis(policy_statement)
                             if violations:
-                                logging.debug("detailed cloudsplainging finding: {}",json.dumps(violations))
+                                logging.debug("detailed cloudsplaining finding: {}",json.dumps(violations))
                                 return CheckResult.FAILED
                     except Exception as e:
                         # this might occur with templated iam policies where ARN is not in place or similar
