@@ -125,11 +125,13 @@ class Runner(BaseRunner):
                                     evaluations=variable_evaluations,
                                     check_class=check.__class__.__module__,
                                     file_abs_path=file_abs_path,
-                                    entity_tags=tags,
+                                    entity_tags=tags
                                 )
+
                                 breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
                                 if breadcrumb:
                                     record = GraphRecord(record, breadcrumb)
+                                record.set_guideline(check.guideline)
                                 report.add_record(record=record)
 
     def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter) -> Report:
@@ -157,12 +159,12 @@ class Runner(BaseRunner):
                     evaluations={},
                     check_class=check.__class__.__module__,
                     file_abs_path=entity_file_abs_path,
-                    entity_tags={} if not entity.get("Tags") else cfn_utils.parse_entity_tags(entity.get("Tags")),
+                    entity_tags={} if not entity.get("Tags") else cfn_utils.parse_entity_tags(entity.get("Tags"))
                 )
                 if self.breadcrumbs:
                     breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
                     if breadcrumb:
                         record = GraphRecord(record, breadcrumb)
-
+                record.set_guideline(check.guideline)
                 report.add_record(record=record)
         return report
