@@ -10,18 +10,22 @@ class SourceType:
 @dataclass
 class BCSourceType:
     VSCODE = 'vscode'
+    JETBRAINS = 'jetbrains'
     CLI = 'cli'
     KUBERNETES_WORKLOADS = 'kubernetesWorkloads'
     GITHUB_ACTIONS = 'githubActions'
+    CODEBUILD = 'codebuild'
     DISABLED = 'disabled'  # use this as a placeholder for generic no-upload logic
 
 
 SourceTypes = {
     BCSourceType.VSCODE: SourceType(BCSourceType.VSCODE, False),
+    BCSourceType.JETBRAINS: SourceType(BCSourceType.JETBRAINS, False),
     BCSourceType.CLI: SourceType(BCSourceType.CLI, True),
     BCSourceType.KUBERNETES_WORKLOADS: SourceType(BCSourceType.KUBERNETES_WORKLOADS, True),
     BCSourceType.GITHUB_ACTIONS: SourceType(BCSourceType.GITHUB_ACTIONS, True),
-    BCSourceType.DISABLED: SourceType(BCSourceType.VSCODE, False)
+    BCSourceType.DISABLED: SourceType(BCSourceType.VSCODE, False),
+    BCSourceType.CODEBUILD: SourceType(BCSourceType.CODEBUILD, True)
 }
 
 
