@@ -27,6 +27,7 @@ from checkov.common.bridgecrew.wrapper import reduce_scan_reports, persist_check
     enrich_and_persist_checks_metadata
 from checkov.common.models.consts import SUPPORTED_FILE_EXTENSIONS
 from checkov.common.runners.base_runner import filter_ignored_paths
+from checkov.common.util.http_utils import normalize_prisma_url
 from checkov.version import version as checkov_version
 
 EMAIL_PATTERN = r"[^@]+@[^@]+\.[^@]+"
@@ -62,13 +63,14 @@ class BcPlatformIntegration(object):
         self.timestamp = None
         self.scan_reports = []
         self.api_url = os.getenv('BC_API_URL', "https://www.bridgecrew.cloud")
-        self.prisma_url = os.getenv("PRISMA_API_URL")
+        self.prisma_url = normalize_prisma_url(os.getenv("PRISMA_API_URL"))
         if self.prisma_url:
             self.api_url = f"{self.prisma_url}/bridgecrew"
         self.bc_source = None
         self.bc_source_version = None
         self.integrations_api_url = f"{self.api_url}/api/v1/integrations/types/checkov"
         self.guidelines_api_url = f"{self.api_url}/api/v1/guidelines"
+        self.customer_all_guidelines_api_url = f"{self.api_url}/api/v1/guidelines/customer"
         self.onboarding_url = f"{self.api_url}/api/v1/signup/checkov"
         self.api_token_url = f"{self.api_url}/api/v1/integrations/apiToken"
         self.suppressions_url = f"{self.api_url}/api/v1/suppressions"
@@ -79,6 +81,7 @@ class BcPlatformIntegration(object):
         self.platform_integration_configured = False
         self.http = None
         self.excluded_paths = []
+        self.bc_skip_mapping = False
 
     @staticmethod
     def is_bc_token(token: str) -> bool:
@@ -91,10 +94,15 @@ class BcPlatformIntegration(object):
         # This is a Prisma Cloud token
         if not self.prisma_url:
             raise ValueError("Got a prisma token, but the env variable PRISMA_API_URL is not set")
+        elif '::' not in self.bc_api_key:
+            raise ValueError("PRISMA_API_URL was set, but the API key does not appear to be a valid Prisma API key "
+                             "(must be in format key::secret)")
         username, password = self.bc_api_key.split('::')
         request = self.http.request("POST", f"{self.prisma_url}/login",
                                     body=json.dumps({"username": username, "password": password}),
                                     headers={"Content-Type": "application/json"})
+        if request.status == 401:
+            raise BridgecrewAuthError()
         token = json.loads(request.data.decode("utf8"))['token']
         return token
 
@@ -133,6 +141,9 @@ class BcPlatformIntegration(object):
         self.bc_source = source
         self.bc_source_version = source_version
 
+        if self.prisma_url:
+            logging.info(f'Using Prisma API URL: {self.prisma_url}')
+
         if self.bc_source.upload_results:
             try:
                 self.skip_fixes = True  # no need to run fixes on CI integration
@@ -158,6 +169,9 @@ class BcPlatformIntegration(object):
             except JSONDecodeError as e:
                 logging.error(f"Response of {self.integrations_api_url} is not a valid JSON\n{e}")
                 raise e
+            except BridgecrewAuthError as e:
+                logging.error("Received an error response during authentication")
+                raise e
 
         self.get_id_mapping()
 
@@ -167,6 +181,8 @@ class BcPlatformIntegration(object):
         token = self.get_auth_token()
         request = self.http.request("POST", self.integrations_api_url, body=json.dumps({"repoId": repo_id}),
                                     headers={"Authorization": token, "Content-Type": "application/json"})
+        if request.status == 403:
+            raise BridgecrewAuthError()
         response = json.loads(request.data.decode("utf8"))
         while ('Message' in response or 'message' in response):
             if 'Message' in response and response['Message'] == UNAUTHORIZED_MESSAGE:
@@ -328,20 +344,26 @@ class BcPlatformIntegration(object):
         return self.ckv_to_bc_id_mapping
 
     def get_checkov_mapping_metadata(self) -> Optional[dict]:
-        BC_SKIP_MAPPING = os.getenv("BC_SKIP_MAPPING", "FALSE")
-        if BC_SKIP_MAPPING.upper() == "TRUE":
+        if self.bc_skip_mapping is True:
             logging.debug(f"Skipped mapping API call")
             self.ckv_to_bc_id_mapping = {}
             return
+        guidelines_url = self.guidelines_api_url
+        headers = {}
         try:
-            request = self.http.request("GET", self.guidelines_api_url)
+            if (self.bc_api_key is not None):
+                guidelines_url = self.customer_all_guidelines_api_url
+                headers = {"Authorization": self.get_auth_token(), "Content-Type": "application/json"}
+            if not self.http:
+                self.setup_http_manager()
+            request = self.http.request("GET", guidelines_url, headers=headers)
             response = json.loads(request.data.decode("utf8"))
             self.guidelines = response["guidelines"]
             self.bc_id_mapping = response.get("idMapping")
             self.ckv_to_bc_id_mapping = {ckv_id: bc_id for (bc_id, ckv_id) in self.bc_id_mapping.items()}
             logging.debug(f"Got checkov mappings from Bridgecrew BE")
         except Exception as e:
-            logging.debug(f"Failed to get the guidelines from {self.guidelines_api_url}, error:\n{e}")
+            logging.debug(f"Failed to get the guidelines from {guidelines_url}, error:\n{e}")
             self.ckv_to_bc_id_mapping = {}
             return
 
