@@ -1,6 +1,8 @@
 import argparse
 import itertools
-import json
+from json import dumps, JSONEncoder
+from lark import Tree
+import datetime
 import logging
 import os
 from abc import abstractmethod
@@ -13,14 +15,17 @@ from checkov.common.output.baseline import Baseline
 from checkov.common.output.report import Report
 from checkov.common.runners.base_runner import BaseRunner
 from checkov.common.util import data_structures_utils
+from checkov.common.util.json_utils import CustomJSONEncoder
 from checkov.runner_filter import RunnerFilter
 from checkov.terraform.context_parsers.registry import parser_registry
 from checkov.terraform.runner import Runner as tf_runner
 from checkov.terraform.parser import Parser
-
+from checkov.common.parallelizer.parallel_runner import parallel_runner
+from checkov.common.util.ext_cyclonedx_xml import ExtXml
+from checkov.common.util.banner import tool as tool_name
 
 CHECK_BLOCK_TYPES = frozenset(["resource", "data", "provider", "module"])
-OUTPUT_CHOICES = ["cli", "json", "junitxml", "github_failed_only", "sarif"]
+OUTPUT_CHOICES = ["cli", "cyclonedx", "json", "junitxml", "github_failed_only", "sarif"]
 OUTPUT_DELIMITER = "\n--- OUTPUT DELIMITER ---\n"
 
 
@@ -36,6 +41,7 @@ class RunnerRegistry:
         self.banner = banner
         self.scan_reports = []
         self.filter_runner_framework()
+        self.tool = tool_name
 
     @abstractmethod
     def extract_entity_details(self, entity: Dict[str, Any]) -> Tuple[str, str, Dict[str, Any]]:
@@ -50,25 +56,30 @@ class RunnerRegistry:
         collect_skip_comments: bool = True,
         repo_root_for_plan_enrichment: Optional[List[Union[str, os.PathLike]]] = None,
     ) -> List[Report]:
-        for runner in self.runners:
-            integration_feature_registry.run_pre_runner()
-            scan_report = runner.run(
-                root_folder,
-                external_checks_dir=external_checks_dir,
-                files=files,
-                runner_filter=self.runner_filter,
-                collect_skip_comments=collect_skip_comments,
-            )
-            integration_feature_registry.run_post_runner(scan_report)
-            if guidelines:
-                RunnerRegistry.enrich_report_with_guidelines(scan_report, guidelines)
-            if repo_root_for_plan_enrichment:
-                enriched_resources = RunnerRegistry.get_enriched_resources(repo_root_for_plan_enrichment)
-                scan_report = Report("terraform_plan").enrich_plan_report(scan_report, enriched_resources)
-                scan_report = Report("terraform_plan").handle_skipped_checks(scan_report, enriched_resources)
-            self.scan_reports.append(scan_report)
+        integration_feature_registry.run_pre_runner()
+        if len(self.runners) == 1:
+            reports = [self.runners[0].run(root_folder, external_checks_dir=external_checks_dir, files=files,
+                                           runner_filter=self.runner_filter, collect_skip_comments=collect_skip_comments)]
+        else:
+            reports = parallel_runner.run_function(
+                lambda runner: runner.run(root_folder, external_checks_dir=external_checks_dir, files=files,
+                                          runner_filter=self.runner_filter, collect_skip_comments=collect_skip_comments),
+                self.runners, 1)
+
+        for scan_report in reports:
+            self._handle_report(scan_report, guidelines, repo_root_for_plan_enrichment)
         return self.scan_reports
 
+    def _handle_report(self, scan_report, guidelines, repo_root_for_plan_enrichment):
+        integration_feature_registry.run_post_runner(scan_report)
+        if guidelines:
+            RunnerRegistry.enrich_report_with_guidelines(scan_report, guidelines)
+        if repo_root_for_plan_enrichment:
+            enriched_resources = RunnerRegistry.get_enriched_resources(repo_root_for_plan_enrichment)
+            scan_report = Report("terraform_plan").enrich_plan_report(scan_report, enriched_resources)
+            scan_report = Report("terraform_plan").handle_skipped_checks(scan_report, enriched_resources)
+        self.scan_reports.append(scan_report)
+
     def print_reports(
         self,
         scan_reports: List[Report],
@@ -79,16 +90,18 @@ class RunnerRegistry:
     ) -> Literal[0, 1]:
         output_formats = set(config.output)
 
-        if "cli" in config.output:
+        if "cli" in config.output and not config.quiet:
             print(f"{self.banner}\n")
         exit_codes = []
+        cli_reports = []
         report_jsons = []
         sarif_reports = []
         junit_reports = []
+        cyclonedx_reports = []
         for report in scan_reports:
             if not report.is_empty():
                 if "json" in config.output:
-                    report_jsons.append(report.get_dict(is_quiet=config.quiet))
+                    report_jsons.append(report.get_dict(is_quiet=config.quiet, url=url))
                 if "junitxml" in config.output:
                     junit_reports.append(report)
                     # report.print_junit_xml()
@@ -97,32 +110,51 @@ class RunnerRegistry:
                 if "sarif" in config.output:
                     sarif_reports.append(report)
                 if "cli" in config.output:
-                    report.print_console(
+                    cli_reports.append(report)
+                if "cyclonedx" in config.output:
+                    cyclonedx_reports.append(report)
+            exit_codes.append(report.get_exit_code(config.soft_fail, config.soft_fail_on, config.hard_fail_on))
+
+        if "cli" in config.output:
+            for report in cli_reports:
+                report.print_console(
+                    is_quiet=config.quiet,
+                    is_compact=config.compact,
+                    created_baseline_path=created_baseline_path,
+                    baseline=baseline,
+                    use_bc_ids=config.output_bc_ids,
+                )
+            if url:
+                print("More details: {}".format(url))
+            output_formats.remove("cli")
+            if output_formats:
+                print(OUTPUT_DELIMITER)
+        if "sarif" in config.output:
+            master_report = Report("merged")
+            print(self.banner)
+            for report in sarif_reports:
+                report.print_console(
                         is_quiet=config.quiet,
                         is_compact=config.compact,
                         created_baseline_path=created_baseline_path,
                         baseline=baseline,
                         use_bc_ids=config.output_bc_ids,
-                    )
-                    if url:
-                        print("More details: {}".format(url))
-                    output_formats.discard("cli")
-                    if output_formats:
-                        print(OUTPUT_DELIMITER)
-            exit_codes.append(report.get_exit_code(config.soft_fail, config.soft_fail_on, config.hard_fail_on))
-        if "sarif" in config.output:
-            master_report = Report(None)
-            for report in sarif_reports:
+                )
                 master_report.failed_checks += report.failed_checks
-            master_report.print_sarif_report()
+                master_report.skipped_checks += report.skipped_checks
+            if url:
+                print("More details: {}".format(url))
+            master_report.write_sarif_output(self.tool)
             output_formats.remove("sarif")
             if output_formats:
                 print(OUTPUT_DELIMITER)
         if "json" in config.output:
-            if len(report_jsons) == 1:
-                print(json.dumps(report_jsons[0], indent=4))
+            if not report_jsons:
+                print(dumps(Report(None).get_summary(), indent=4))
+            elif len(report_jsons) == 1:
+                print(dumps(report_jsons[0], indent=4, cls=CustomJSONEncoder))
             else:
-                print(json.dumps(report_jsons, indent=4))
+                print(dumps(report_jsons, indent=4, cls=CustomJSONEncoder))
             output_formats.remove("json")
             if output_formats:
                 print(OUTPUT_DELIMITER)
@@ -139,8 +171,22 @@ class RunnerRegistry:
             output_formats.remove("junitxml")
             if output_formats:
                 print(OUTPUT_DELIMITER)
-        # if config.output == "cli":
-        # bc_integration.get_report_to_platform(config,scan_reports)
+
+        if "cyclonedx" in config.output:
+            if cyclonedx_reports:
+                # More than one Report - combine Reports first
+                report = Report(None)
+                for r in cyclonedx_reports:
+                    report.passed_checks += r.passed_checks
+                    report.skipped_checks += r.skipped_checks
+                    report.failed_checks += r.failed_checks
+            else:
+                report = cyclonedx_reports[0]
+            cyclonedx_output = ExtXml(bom=report.get_cyclonedx_bom())
+            print(cyclonedx_output.output_as_string())
+            output_formats.remove("cyclonedx")
+            if output_formats:
+                print(OUTPUT_DELIMITER)
 
         exit_code = 1 if 1 in exit_codes else 0
         return exit_code
@@ -148,9 +194,9 @@ class RunnerRegistry:
     def filter_runner_framework(self) -> None:
         if not self.runner_filter:
             return
-        if self.runner_filter.framework is None:
+        if not self.runner_filter.framework:
             return
-        if self.runner_filter.framework == "all":
+        if "all" in self.runner_filter.framework:
             return
         self.runners = [runner for runner in self.runners if runner.check_type in self.runner_filter.framework]
 
