@@ -10,6 +10,12 @@ from checkov.version import version as checkov_version
 logger = logging.getLogger(__name__)
 
 
+def normalize_prisma_url(prisma_url: str):
+    if not prisma_url:
+        return None
+    return prisma_url[0:-1] if prisma_url.endswith('/') else prisma_url
+
+
 def extract_error_message(response: requests.Response):
     if response.content:
         try:
