@@ -10,6 +10,7 @@ from functools import reduce
 import yaml
 
 from checkov.common.output.report import Report
+from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.helm.registry import registry
 from checkov.kubernetes.runner import Runner as k8_runner
@@ -105,9 +106,10 @@ class Runner(BaseRunner):
 
         report = Report(self.check_type)
 
-        for chart_dir in chart_directories:
+        chart_dir_and_meta = parallel_runner.run_function(
+            lambda cd: (cd, self.parse_helm_chart_details(cd)), chart_directories)
+        for chart_dir, chart_meta in chart_dir_and_meta:
             # chart_name = os.path.basename(chart_dir)
-            chart_meta = self.parse_helm_chart_details(chart_dir)
             logging.info(
                 f"Processing chart found at: {chart_dir}, name: {chart_meta['name']}, version: {chart_meta['version']}")
             with tempfile.TemporaryDirectory() as target_dir:
