@@ -1,6 +1,7 @@
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.common.util.type_forcers import force_int
 from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceCheck
+from typing import List
 
 
 class SQLServerAuditPolicyRetentionPeriod(BaseResourceCheck):
@@ -12,8 +13,8 @@ class SQLServerAuditPolicyRetentionPeriod(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
-        if 'retention_in_days' in conf: 
-            retention=force_int(conf['retention_in_days'][0])
+        if 'retention_in_days' in conf:
+            retention = force_int(conf['retention_in_days'][0])
             if retention:
                 if retention < 90:
                     return CheckResult.FAILED
@@ -21,5 +22,8 @@ class SQLServerAuditPolicyRetentionPeriod(BaseResourceCheck):
                     return CheckResult.PASSED
         return CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['retention_in_days']
+
 
 check = SQLServerAuditPolicyRetentionPeriod()
