@@ -1,3 +1,5 @@
+from typing import List
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
@@ -13,11 +15,9 @@ class CloudStorageLogging(BaseResourceCheck):
     def scan_resource_conf(self, conf):
         #check for logging
         if 'logging' in conf:
-            self.evaluated_keys = ['logging']
             if conf['logging'][0]:
                 log_bucket_name = conf['logging'][0]['log_bucket']
-                self.evaluated_keys = ['logging/[0]/log_bucket']
-                if log_bucket_name != None:
+                if log_bucket_name:
                     return CheckResult.PASSED
                 else:
                     return CheckResult.FAILED
@@ -25,4 +25,8 @@ class CloudStorageLogging(BaseResourceCheck):
                 return CheckResult.FAILED
         return CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ["logging/[0]/log_bucket"]
+
+
 check = CloudStorageLogging()
