@@ -1,5 +1,6 @@
-from checkov.terraform.checks.resource.base_check import BaseResourceCheck
-from checkov.terraform.models.enums import CheckResult, CheckCategories
+from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+from checkov.common.models.enums import CheckResult, CheckCategories
+from typing import List
 
 
 class GKEClusterLogging(BaseResourceCheck):
@@ -7,7 +8,7 @@ class GKEClusterLogging(BaseResourceCheck):
         name = "Ensure Stackdriver Logging is set to Enabled on Kubernetes Engine Clusters"
         id = "CKV_GCP_1"
         supported_resources = ['google_container_cluster']
-        categories = [CheckCategories.LOGGING]
+        categories = [CheckCategories.KUBERNETES]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
@@ -22,5 +23,8 @@ class GKEClusterLogging(BaseResourceCheck):
                 return CheckResult.FAILED
         return CheckResult.PASSED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['logging_service']
+
 
 check = GKEClusterLogging()
