@@ -1,5 +1,6 @@
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 from checkov.common.models.enums import CheckResult, CheckCategories
+from typing import List
 
 
 class GKEHasLabels(BaseResourceCheck):
@@ -23,5 +24,8 @@ class GKEHasLabels(BaseResourceCheck):
                 return CheckResult.PASSED
         return CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['resource_labels']
+
 
 check = GKEHasLabels()
