@@ -1,6 +1,6 @@
 import logging
 from checkov.common.parsers.json import parse as json_parse
-from checkov.common.parsers.node import dict_node
+from checkov.common.parsers.node import DictNode
 
 LOGGER = logging.getLogger(__name__)
 
@@ -13,7 +13,7 @@ def parse(filename):
 
     if (
         template is not None
-        and isinstance(template, dict_node)
+        and isinstance(template, DictNode)
         and 'terraform_version' in template
         and 'planned_values' in template
     ):
