@@ -1,4 +1,7 @@
 import os
+import platform
+import re
+import logging
 
 from checkov.terraform.module_loading.content import ModuleContent
 from checkov.terraform.module_loading.loader import ModuleLoader
@@ -10,8 +13,20 @@ class LocalPathLoader(ModuleLoader):
         self.is_external = False
 
     def _is_matching_loader(self) -> bool:
-        return self.module_source.startswith("./") or self.module_source.startswith("../") \
-               or self.module_source.startswith(self.current_dir)
+        if (
+                self.module_source.startswith("./") or
+                self.module_source.startswith("../") or
+                self.module_source.startswith(self.current_dir) or
+                self.module_source.startswith("/")
+            ):
+            return True
+
+        if platform.system() == 'Windows':
+            logging.debug("Platform: Windows")
+            if re.match("[a-zA-Z]:\\\\", self.module_source):
+                return True
+
+        return False
 
     def _load_module(self) -> ModuleContent:
         module_path = os.path.normpath(os.path.join(self.current_dir, self.module_source))
@@ -22,5 +37,9 @@ class LocalPathLoader(ModuleLoader):
 
         return ModuleContent(module_path)
 
+    def _find_module_path(self) -> str:
+        # to determine the exact path here would mimic _load_module()
+        return ""
+
 
 loader = LocalPathLoader()
