@@ -1,28 +1,29 @@
 import datetime
-import io
 import json
 import logging
-import multiprocessing
 import os
 import re
-import sys
 from copy import deepcopy
 from json import dumps, loads, JSONEncoder
 from pathlib import Path
-from typing import Optional, Dict, Mapping, Set, Tuple, Callable, Any, List
+from typing import Optional, Dict, Mapping, Set, Tuple, Callable, Any, List, Type
 
 import deep_merge
 import hcl2
 from lark import Tree
 
+from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.runners.base_runner import filter_ignored_paths
 from checkov.common.util.config_utils import should_scan_hcl_files
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR, RESOLVED_MODULE_ENTRY_NAME
+from checkov.common.util.json_utils import CustomJSONEncoder
 from checkov.common.variables.context import EvaluationContext
 from checkov.terraform.checks.utils.dependency_path_handler import unify_dependency_path
 from checkov.terraform.graph_builder.graph_components.block_types import BlockType
 from checkov.terraform.graph_builder.graph_components.module import Module
 from checkov.terraform.graph_builder.utils import remove_module_dependency_in_path
+from checkov.terraform.module_loading.content import ModuleContent
+from checkov.terraform.module_loading.module_finder import load_tf_modules
 from checkov.terraform.module_loading.registry import module_loader_registry as default_ml_registry, \
     ModuleLoaderRegistry
 from checkov.terraform.parser_utils import eval_string, find_var_blocks
@@ -30,26 +31,17 @@ from checkov.terraform.parser_utils import eval_string, find_var_blocks
 external_modules_download_path = os.environ.get('EXTERNAL_MODULES_DIR', DEFAULT_EXTERNAL_MODULES_DIR)
 
 
-class DefinitionsEncoder(JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, set):
-            return list(obj)
-        elif isinstance(obj, Tree):
-            return str(obj)
-        elif isinstance(obj, datetime.date):
-            return str(obj)
-        return super().default(obj)
-
-
 def _filter_ignored_paths(root, paths, excluded_paths):
     filter_ignored_paths(root, paths, excluded_paths)
     [paths.remove(path) for path in list(paths) if path in [default_ml_registry.external_modules_folder_name]]
 
 
 class Parser:
-    def __init__(self, module_class=Module):
+    def __init__(self, module_class: Type[Module] = Module):
         self.module_class = module_class
         self._parsed_directories = set()
+        self.external_modules_source_map: Dict[Tuple[str, str], str] = {}
+        self.module_address_map: Dict[Tuple[str, str], str] = {}
 
         # This ensures that we don't try to double-load modules
         # Tuple is <file>, <module_index>, <name> (see _load_modules)
@@ -71,6 +63,8 @@ class Parser:
         self.env_vars = env_vars
         self.download_external_modules = download_external_modules
         self.external_modules_download_path = external_modules_download_path
+        self.external_modules_source_map = {}
+        self.module_address_map = {}
         self.tf_var_files = tf_var_files
         self.scan_hcl = should_scan_hcl_files()
 
@@ -96,18 +90,25 @@ class Parser:
                         download_external_modules: bool = False,
                         external_modules_download_path: str = DEFAULT_EXTERNAL_MODULES_DIR,
                         excluded_paths: Optional[List[str]] = None,
-                        vars_files: Optional[List[str]] = None):
+                        vars_files: Optional[List[str]] = None,
+                        external_modules_content_cache: Optional[Dict[str, ModuleContent]] = None):
         self._init(directory, out_definitions, out_evaluations_context, out_parsing_errors, env_vars,
                    download_external_modules, external_modules_download_path, excluded_paths)
         self._parsed_directories.clear()
+        default_ml_registry.root_dir = directory
         default_ml_registry.download_external_modules = download_external_modules
         default_ml_registry.external_modules_folder_name = external_modules_download_path
+        default_ml_registry.module_content_cache = external_modules_content_cache if external_modules_content_cache else {}
+        load_tf_modules(directory)
         self._parse_directory(dir_filter=lambda d: self._check_process_dir(d), vars_files=vars_files)
 
-    @staticmethod
-    def parse_file(file: str, parsing_errors: Dict[str, Exception] = None, scan_hcl = False) -> Optional[Dict]:
+    def parse_file(self, file: str, parsing_errors: Dict[str, Exception] = None, scan_hcl = False) -> Optional[Dict]:
         if file.endswith(".tf") or file.endswith(".tf.json") or (scan_hcl and file.endswith(".hcl")):
-            return _load_or_die_quietly(Path(file), parsing_errors)
+            parse_result = _load_or_die_quietly(Path(file), parsing_errors)
+            if parse_result:
+                parse_result = self._serialize_definitions(parse_result)
+                parse_result = self._clean_parser_types(parse_result)
+                return parse_result
         else:
             return None
 
@@ -143,11 +144,12 @@ class Parser:
 
         if include_sub_dirs:
             for sub_dir, d_names, f_names in os.walk(self.directory):
+                # filter subdirectories for future iterations (we filter files while iterating the directory)
                 _filter_ignored_paths(sub_dir, d_names, self.excluded_paths)
-                _filter_ignored_paths(sub_dir, f_names, self.excluded_paths)
                 if dir_filter(os.path.abspath(sub_dir)):
                     self._internal_dir_load(sub_dir, module_loader_registry, dir_filter,
-                                            keys_referenced_as_modules, vars_files=vars_files)
+                                            keys_referenced_as_modules, vars_files=vars_files,
+                                            root_dir=self.directory, excluded_paths=self.excluded_paths)
         else:
             self._internal_dir_load(self.directory, module_loader_registry, dir_filter,
                                     keys_referenced_as_modules, vars_files=vars_files)
@@ -163,7 +165,9 @@ class Parser:
                            keys_referenced_as_modules: Set[str],
                            specified_vars: Optional[Mapping[str, str]] = None,
                            module_load_context: Optional[str] = None,
-                           vars_files: Optional[List[str]] = None):
+                           vars_files: Optional[List[str]] = None,
+                           root_dir: Optional[str] = None,
+                           excluded_paths: Optional[List[str]] = None):
         """
     See `parse_directory` docs.
         :param directory:                  Directory in which .tf and .tfvars files will be loaded.
@@ -186,7 +190,13 @@ class Parser:
         json_tfvars: Optional[os.DirEntry] = None
         auto_vars_files: List[os.DirEntry] = []  # *.auto.tfvars / *.auto.tfvars.json
         explicit_var_files: List[os.DirEntry] = []  # files passed with --var-file; only process the ones that are in this directory
-        for file in os.scandir(directory):
+
+        dir_contents = list(os.scandir(directory))
+        if excluded_paths:
+            filter_ignored_paths(root_dir, dir_contents, excluded_paths)
+
+        tf_files_to_load = []
+        for file in dir_contents:
             # Ignore directories and hidden files
             try:
                 if not file.is_file() or file.name.startswith("."):
@@ -199,27 +209,23 @@ class Parser:
             # See: https://www.terraform.io/docs/configuration/variables.html#variable-definitions-tfvars-files
             if file.name == "terraform.tfvars.json":
                 json_tfvars = file
-                continue
             elif file.name == "terraform.tfvars":
                 hcl_tfvars = file
-                continue
             elif file.name.endswith(".auto.tfvars.json") or file.name.endswith(".auto.tfvars"):
                 auto_vars_files.append(file)
-                continue
             elif vars_files and file.path in vars_files:
                 explicit_var_files.append(file)
-                continue
 
             # Resource files
-            if file.name.endswith(".tf") or (self.scan_hcl and file.name.endswith('.hcl')):  # TODO: add support for .tf.json
-                data = _load_or_die_quietly(file, self.out_parsing_errors)
-            else:
-                continue
+            elif file.name.endswith(".tf") or (self.scan_hcl and file.name.endswith('.hcl')):  # TODO: add support for .tf.json
+                tf_files_to_load.append(file)
 
-            if not data:  # failed loads or empty files
-                continue
+        files_to_data = self._load_files(tf_files_to_load)
 
-            self.out_definitions[file.path] = data
+        for file, data in sorted(files_to_data, key=lambda x: x[0]):
+            if not data:
+                continue
+            self.out_definitions[file] = data
 
             # Load variable defaults
             #  (see https://www.terraform.io/docs/configuration/variables.html#declaring-an-input-variable)
@@ -234,8 +240,8 @@ class Parser:
 
                         default_value = var_definition.get("default")
                         if default_value is not None and isinstance(default_value, list):
-                            self.external_variables_data.append((var_name, default_value[0], file.path))
-                            var_value_and_file_map[var_name] = default_value[0], file.path
+                            self.external_variables_data.append((var_name, default_value[0], file))
+                            var_value_and_file_map[var_name] = default_value[0], file
 
         # Stage 2: Load vars in proper order:
         #          https://www.terraform.io/docs/configuration/variables.html#variable-definition-precedence
@@ -254,8 +260,7 @@ class Parser:
             var_value_and_file_map[key[7:]] = value, f"env:{key}"
             self.external_variables_data.append((key[7:], value, f"env:{key}"))
         if hcl_tfvars:  # terraform.tfvars
-            data = _load_or_die_quietly(hcl_tfvars, self.out_parsing_errors,
-                                        clean_definitions=False)
+            data = _load_or_die_quietly(hcl_tfvars, self.out_parsing_errors, clean_definitions=False)
             if data:
                 var_value_and_file_map.update({k: (_safe_index(v, 0), hcl_tfvars.path) for k, v in data.items()})
                 self.external_variables_data.extend([(k, _safe_index(v, 0), hcl_tfvars.path) for k, v in data.items()])
@@ -264,19 +269,20 @@ class Parser:
             if data:
                 var_value_and_file_map.update({k: (v, json_tfvars.path) for k, v in data.items()})
                 self.external_variables_data.extend([(k, v, json_tfvars.path) for k, v in data.items()])
-        for var_file in sorted(auto_vars_files, key=lambda e: e.name):
-            data = _load_or_die_quietly(var_file, self.out_parsing_errors)
-            if data:
-                var_value_and_file_map.update({k: (v, var_file.path) for k, v in data.items()})
-                self.external_variables_data.extend([(k, v, var_file.path) for k, v in data.items()])
 
-        # it's possible that os.scandir returned the var files in a different order than they were specified
-        explicit_var_files.sort(key=lambda f: vars_files.index(f.path))
-        for var_file in explicit_var_files:
-            data = _load_or_die_quietly(var_file, self.out_parsing_errors)
+        auto_var_files_to_data = self._load_files(auto_vars_files)
+        for var_file, data in sorted(auto_var_files_to_data, key=lambda x: x[0]):
             if data:
-                var_value_and_file_map.update({k: (v, var_file.path) for k, v in data.items()})
-                self.external_variables_data.extend([(k, v, var_file.path) for k, v in data.items()])
+                var_value_and_file_map.update({k: (v, var_file) for k, v in data.items()})
+                self.external_variables_data.extend([(k, v, var_file) for k, v in data.items()])
+
+        explicit_var_files_to_data = self._load_files(explicit_var_files)
+        # it's possible that os.scandir returned the var files in a different order than they were specified
+        for var_file, data in sorted(explicit_var_files_to_data, key=lambda x: vars_files.index(x[0])):
+            if data:
+                var_value_and_file_map.update({k: (v, var_file) for k, v in data.items()})
+                self.external_variables_data.extend([(k, v, var_file) for k, v in data.items()])
+
         if specified_vars:  # specified
             var_value_and_file_map.update({k: (v, "manual specification") for k, v in specified_vars.items()})
             self.external_variables_data.extend([(k, v, "manual specification") for k, v in specified_vars.items()])
@@ -316,6 +322,23 @@ class Parser:
                 # load, forcing things through without complete resolution.
                 force_final_module_load = True
 
+    def _load_files(self, files):
+        def _load_file(file):
+            parsing_errors = {}
+            result = _load_or_die_quietly(file, parsing_errors)
+            # the exceptions type can un-pickleable
+            for path, e in parsing_errors.items():
+                parsing_errors[path] = Exception(str(e))
+
+            return (file.path, result), parsing_errors
+
+        results = parallel_runner.run_function(_load_file, files)
+        files_to_data = []
+        for result, parsing_errors in results:
+            self.out_parsing_errors.update(parsing_errors)
+            files_to_data.append(result)
+        return files_to_data
+
     def _load_modules(self, root_dir: str, module_loader_registry: ModuleLoaderRegistry,
                       dir_filter: Callable[[str], bool], module_load_context: Optional[str],
                       keys_referenced_as_modules: Set[str], ignore_unresolved_params: bool = False) -> bool:
@@ -393,60 +416,65 @@ class Parser:
                     if version and isinstance(version, list):
                         version = version[0]
                     try:
-                        with module_loader_registry.load(root_dir, source, version) as content:
-                            if not content.loaded():
+                        content = module_loader_registry.load(root_dir, source, version)
+                        if not content.loaded():
+                            logging.info(f'Got no content for {source}:{version}')
+                            continue
+
+                        self._internal_dir_load(directory=content.path(),
+                                                module_loader_registry=module_loader_registry,
+                                                dir_filter=dir_filter, specified_vars=specified_vars,
+                                                module_load_context=module_load_context,
+                                                keys_referenced_as_modules=keys_referenced_as_modules)
+
+                        module_definitions = {path: self.out_definitions[path] for path in
+                                              list(self.out_definitions.keys()) if
+                                              os.path.dirname(path) == content.path()}
+
+                        if not module_definitions:
+                            continue
+
+                        # NOTE: Modules are put into the main TF definitions structure "as normal" with the
+                        #       notable exception of the file name. For loaded modules referrer information is
+                        #       appended to the file name to create this format:
+                        #         <file_name>[<referred_file>#<referrer_index>]
+                        #       For example:
+                        #         /the/path/module/my_module.tf[/the/path/main.tf#0]
+                        #       The referrer and index allow a module allow a module to be loaded multiple
+                        #       times with differing data.
+                        #
+                        #       In addition, the referring block will have a "__resolved__" key added with a
+                        #       list pointing to the location of the module data that was resolved. For example:
+                        #         "__resolved__": ["/the/path/module/my_module.tf[/the/path/main.tf#0]"]
+
+                        resolved_loc_list = module_call_data.get(RESOLVED_MODULE_ENTRY_NAME)
+                        if resolved_loc_list is None:
+                            resolved_loc_list = []
+                            module_call_data[RESOLVED_MODULE_ENTRY_NAME] = resolved_loc_list
+
+                        # NOTE: Modules can load other modules, so only append referrer information where it
+                        #       has not already been added.
+                        keys = list(module_definitions.keys())
+                        for key in keys:
+                            if key.endswith("]") or file.endswith("]"):
                                 continue
+                            keys_referenced_as_modules.add(key)
+                            new_key = f"{key}[{file}#{module_index}]"
+                            module_definitions[new_key] = module_definitions[key]
+                            del module_definitions[key]
+                            del self.out_definitions[key]
+                            if new_key not in resolved_loc_list:
+                                resolved_loc_list.append(new_key)
+                            if (file, module_call_name) not in self.module_address_map:
+                                self.module_address_map[(file, module_call_name)] = str(module_index)
+                        resolved_loc_list.sort()  # For testing, need predictable ordering
 
-                            self._internal_dir_load(directory=content.path(),
-                                                    module_loader_registry=module_loader_registry,
-                                                    dir_filter=dir_filter, specified_vars=specified_vars,
-                                                    module_load_context=module_load_context,
-                                                    keys_referenced_as_modules=keys_referenced_as_modules)
+                        if all_module_definitions:
+                            deep_merge.merge(all_module_definitions, module_definitions)
+                        else:
+                            all_module_definitions = module_definitions
 
-                            module_definitions = {path: self.out_definitions[path] for path in
-                                                  list(self.out_definitions.keys()) if
-                                                  os.path.dirname(path) == content.path()}
-
-                            if not module_definitions:
-                                continue
-
-                            # NOTE: Modules are put into the main TF definitions structure "as normal" with the
-                            #       notable exception of the file name. For loaded modules referrer information is
-                            #       appended to the file name to create this format:
-                            #         <file_name>[<referred_file>#<referrer_index>]
-                            #       For example:
-                            #         /the/path/module/my_module.tf[/the/path/main.tf#0]
-                            #       The referrer and index allow a module allow a module to be loaded multiple
-                            #       times with differing data.
-                            #
-                            #       In addition, the referring block will have a "__resolved__" key added with a
-                            #       list pointing to the location of the module data that was resolved. For example:
-                            #         "__resolved__": ["/the/path/module/my_module.tf[/the/path/main.tf#0]"]
-
-                            resolved_loc_list = module_call_data.get(RESOLVED_MODULE_ENTRY_NAME)
-                            if resolved_loc_list is None:
-                                resolved_loc_list = []
-                                module_call_data[RESOLVED_MODULE_ENTRY_NAME] = resolved_loc_list
-
-                            # NOTE: Modules can load other modules, so only append referrer information where it
-                            #       has not already been added.
-                            keys = list(module_definitions.keys())
-                            for key in keys:
-                                if key.endswith("]") or file.endswith("]"):
-                                    continue
-                                keys_referenced_as_modules.add(key)
-                                new_key = f"{key}[{file}#{module_index}]"
-                                module_definitions[new_key] = module_definitions[key]
-                                del module_definitions[key]
-                                del self.out_definitions[key]
-                                if new_key not in resolved_loc_list:
-                                    resolved_loc_list.append(new_key)
-                            resolved_loc_list.sort()  # For testing, need predictable ordering
-
-                            if all_module_definitions:
-                                deep_merge.merge(all_module_definitions, module_definitions)
-                            else:
-                                all_module_definitions = module_definitions
+                        self.external_modules_source_map[(source, version)] = content.path()
                     except Exception as e:
                         logging.warning("Unable to load module (source=\"%s\" version=\"%s\"): %s",
                                         source, version, e)
@@ -465,21 +493,35 @@ class Parser:
         external_modules_download_path: str = DEFAULT_EXTERNAL_MODULES_DIR,
         parsing_errors: Optional[Dict[str, Exception]] = None,
         excluded_paths: Optional[List[str]] = None,
-        vars_files: Optional[List[str]] = None
-    ) -> Tuple[Module, Dict[str, List[List[str]]], Dict[str, Dict[str, Any]]]:
-        tf_definitions = {}
+        vars_files: Optional[List[str]] = None,
+        external_modules_content_cache: Optional[Dict[str, ModuleContent]] = None
+    ) -> Tuple[Module, Dict[str, Dict[str, Any]]]:
+        tf_definitions: Dict[str, Dict[str, Any]] = {}
         self.parse_directory(directory=source_dir, out_definitions=tf_definitions, out_evaluations_context={},
                              out_parsing_errors=parsing_errors if parsing_errors is not None else {},
                              download_external_modules=download_external_modules,
                              external_modules_download_path=external_modules_download_path, excluded_paths=excluded_paths,
-                             vars_files=vars_files)
+                             vars_files=vars_files, external_modules_content_cache=external_modules_content_cache)
         tf_definitions = self._clean_parser_types(tf_definitions)
         tf_definitions = self._serialize_definitions(tf_definitions)
-        return self.parse_hcl_module_from_tf_definitions(tf_definitions, source_dir, source)
 
-    def parse_hcl_module_from_tf_definitions(self, tf_definitions, source_dir, source, excluded_paths: List[str]=None):
+        module, tf_definitions = self.parse_hcl_module_from_tf_definitions(tf_definitions, source_dir, source)
+        return module, tf_definitions
+
+    def parse_hcl_module_from_tf_definitions(
+        self,
+        tf_definitions: Dict[str, Dict[str, Any]],
+        source_dir: str,
+        source: str,
+    ) -> Tuple[Module, Dict[str, Dict[str, Any]]]:
         module_dependency_map, tf_definitions, dep_index_mapping = self.get_module_dependency_map(tf_definitions)
-        module = self.get_new_module(source_dir, module_dependency_map, dep_index_mapping)
+        module = self.get_new_module(
+            source_dir=source_dir,
+            module_dependency_map=module_dependency_map,
+            module_address_map=self.module_address_map,
+            external_modules_source_map=self.external_modules_source_map,
+            dep_index_mapping=dep_index_mapping,
+        )
         self.add_tfvars(module, source)
         copy_of_tf_definitions = deepcopy(tf_definitions)
         for file_path, blocks in copy_of_tf_definitions.items():
@@ -489,7 +531,7 @@ class Parser:
                 except Exception as e:
                     logging.error(f'Failed to add block {blocks[block_type]}. Error:')
                     logging.error(e, exc_info=True)
-        return module, module_dependency_map, tf_definitions
+        return module, tf_definitions
 
     @staticmethod
     def _clean_parser_types(conf: dict) -> dict:
@@ -536,7 +578,7 @@ class Parser:
 
     @staticmethod
     def _serialize_definitions(tf_definitions):
-        return loads(dumps(tf_definitions, cls=DefinitionsEncoder))
+        return loads(dumps(tf_definitions, cls=CustomJSONEncoder))
 
     @staticmethod
     def get_next_vertices(evaluated_files: list, unevaluated_files: list) -> (list, list):
@@ -589,7 +631,7 @@ class Parser:
         """
         module_dependency_map = {}
         copy_of_tf_definitions = {}
-        dep_index_mapping = {}
+        dep_index_mapping: Dict[Tuple[str, str], List[str]] = {}
         origin_keys = list(filter(lambda k: not k.endswith(']'), tf_definitions.keys()))
         unevaluated_keys = list(filter(lambda k: k.endswith(']'), tf_definitions.keys()))
         for file_path in origin_keys:
@@ -611,7 +653,7 @@ class Parser:
                     module_dependency_map[dir_name] += current_deps
                 copy_of_tf_definitions[path] = deepcopy(tf_definitions[file_path])
                 origin_keys.append(path)
-                dep_index_mapping[path] = module_dependency_num
+                dep_index_mapping.setdefault((path, module_dependency), []).append(module_dependency_num)
             next_level, unevaluated_keys = Parser.get_next_vertices(origin_keys, unevaluated_keys)
         for key, dep_trails in module_dependency_map.items():
             hashes = set()
@@ -626,8 +668,20 @@ class Parser:
         return module_dependency_map, copy_of_tf_definitions, dep_index_mapping
 
     @staticmethod
-    def get_new_module(source_dir, module_dependency_map, dep_index_mapping):
-        return Module(source_dir, module_dependency_map, dep_index_mapping)
+    def get_new_module(
+            source_dir: str,
+            module_dependency_map: Dict[str, List[List[str]]],
+            module_address_map: Dict[Tuple[str, str], str],
+            external_modules_source_map: Dict[Tuple[str, str], str],
+            dep_index_mapping: Dict[Tuple[str, str], List[str]],
+    ) -> Module:
+        return Module(
+            source_dir=source_dir,
+            module_dependency_map=module_dependency_map,
+            module_address_map=module_address_map,
+            external_modules_source_map=external_modules_source_map,
+            dep_index_mapping=dep_index_mapping
+        )
 
     def add_tfvars(self, module, source):
         if not self.external_variables_data:
