@@ -145,7 +145,8 @@ class Runner(BaseRunner):
                         entity_tags=entity.get('tags', {}),
                         evaluations=entity_evaluations,
                         check_class=check.__class__.__module__,
-                        file_abs_path=os.path.abspath(full_file_path)
+                        file_abs_path=os.path.abspath(full_file_path),
+                        resource_address=entity_context.get('address')
                     )
                     if self.breadcrumbs:
                         breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
